%global genericname gdata

Name:          %{genericname}-java
Version:       1.47.1
Release:       1%{?dist}
Summary:       Client libraries to write Google Data API client applications in Java
License:       ASL 2.0
URL:           http://code.google.com/p/gdata-java-client/
Source0:       http://gdata-java-client.googlecode.com/files/%{genericname}-src.java-%{version}.zip
Source1:       http://central.maven.org/maven2/com/google/gdata/core/%{version}/core-%{version}.pom
BuildArch:     noarch

BuildRequires: java-devel >= 1:1.6.0
BuildRequires: jpackage-utils
BuildRequires: ant
BuildRequires: javamail jboss-servlet-2.5-api
BuildRequires: guava jsr-305 google-oauth-java-client
Requires:      java-headless
Requires:      jpackage-utils

%description
The client library provides tools and an abstraction layer, letting you
easily construct queries and use response data without having to create
HTTP requests or process HTTP responses by hand. Each client library
provides classes that correspond to the elements and data types used by
the Google Data APIs. Each client library also provides extensions for
specific Google services that have Data APIs.

%package javadoc
Summary:           Javadoc for gdata
Requires:          %name = %{version}-%{release}

%description javadoc
gdata development documentation.

%prep
%setup -q -n gdata

find . -name "*.class" -print -delete
find . -name "*.jar" -print -delete

pushd java

rm -rf lib/* gdata/java/deps/* classes doc

properties=build-src/build.properties
for jars in \
  "servlet jboss-servlet-2.5-api" \
  "mail javamail/mail" \
  "activation activation" \
  "guava guava" \
  "google-jsr305 jsr-305" \
  "google-oauth-client google-oauth-java-client/google-oauth-client"
do
  f=`echo $jars | gawk '{print $1;}'`
  g=`echo $jars | gawk '{print $2;}'`
  %{__sed} -i -e "/^${f}/s|=.*$|=`build-classpath ${g}`|" $properties
done

for i in $(ls manifest/*.manifest); do
  %{__sed} -i '/class-path/I d' $i
  echo "Export-Package: $(grep '^Name' $i | sed -e 's|^Name: *||' -e 's|/|.|g' -e 's|.$||');version=\"%{version}\"" >> $i
done

popd


%build
pushd java
ant -lib lib/%{genericname}-core-1.0.jar:lib/%{genericname}-client-1.0.jar -buildfile build-src.xml clean build

find src -name '*.java' |xargs javadoc -classpath \
  `build-classpath javamail guava jsr-305 google-oauth-java-client/google-oauth-client`:/etc/alternatives/java_sdk_openjdk/lib/tools.jar -d doc
popd


%install
#jars
pushd java
pushd lib
install -d $RPM_BUILD_ROOT%{_javadir}/%{genericname}

for i in `ls *.jar`; do
  x=`echo $i | tr -d [:digit:]`
  install -m644 $i $RPM_BUILD_ROOT%{_javadir}/%{genericname}/${x%%-\.\.jar}.jar
done
popd

# javadoc
install -d $RPM_BUILD_ROOT%{_javadocdir}/%{genericname}
cp -rp doc/* $RPM_BUILD_ROOT%{_javadocdir}/%{genericname}
popd

# pom dir
install -d -m 755 $RPM_BUILD_ROOT%{_mavenpomdir}

# pom
# Only gdata-core included for now, feel free to add more artifacts to pom file if you need
install -pm 644 %{SOURCE1} $RPM_BUILD_ROOT%{_mavenpomdir}/JPP.%{genericname}-%{genericname}-core.pom

# depmap
%add_maven_depmap JPP.%{genericname}-%{genericname}-core.pom %{genericname}/%{genericname}-core.jar -a "com.google.%{genericname}:%{genericname}-core"

sed -i '/gdata-core.jar/d' .mfiles

%files -f .mfiles
%doc RELEASE_NOTES.txt
%license COPYING
%{_javadir}/%{genericname}

%files javadoc
%license COPYING
%{_javadocdir}/%{genericname}


%changelog
* Tue Feb 24 2015 gil cattaneo <puntogil@libero.it> 1.47.1-1
- Update to 1.47.1

* Tue Sep  4 2012 Mikolaj Izdebski <mizdebsk@redhat.com> - 1.45.0-5
- Install COPYING file with javadoc package
- Update to current packaging guidelines

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.45.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.45.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Aug 03 2011 Marek Goldmann <mgoldman@redhat.com> - 1.45.0-2
- Added maven depmap for gdata-core

* Fri Jul 01 2011 Sandro Mathys <red at fedoraproject.org> - 1.45.0-1
- New upstream version 1.45.0
- Added Export-Package data to manifest files (OSGi)

* Wed Mar 16 2011 Alexander Kurtakov <akurtako@redhat.com> 1.41.2-3
- Build against servlet25.

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.41.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Jun 17 2010 Lubomir Rintel <lkundrak@v3.sk> - 1.41.2-1
- Rebase to later version, so that we include analytics api

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.28.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.28.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Dec 18 2008 Sandro Mathys <red at fedoraproject.org> - 1.28.0-1
- New version

* Thu Dec 18 2008 Sandro Mathys <red at fedoraproject.org> - 1.26.0-2
- The changes to the build.properties file are now applied with a for loop
and sed instead of a patch
- The paths to the 3rd-party libraries (i.e. currently only javamail.jar)
for the javadoc generation are now looked up with build-classpath instead of
being hardcoded

* Tue Dec 16 2008 Sandro Mathys <red at fedoraproject.org> - 1.26.0-1
- initial build (thanks Rudolf 'che' Kastl for the help)
